<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>ReminderDialog</name>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="14"/>
        <source>Restart the computer to use the system and the applications properly</source>
        <translation>Indítsa újra a számítógépet a rendszer és az alkalmazások megfelelő használatához.</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="15"/>
        <source>Make sure all data had been saved first</source>
        <translation>Győződjön meg arról, hogy minden adat mentésre került</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="20"/>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="20"/>
        <source>Shut down</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="23"/>
        <source>Reboot</source>
        <translation>Újraindítás</translation>
    </message>
</context>
</TS>